LightGridLeaf

Struct LightGridLeaf 

pub struct LightGridLeaf {
    pub mins: UVec3,
    /* private fields */
}

Fields

mins: UVec3

Implementations

Source

impl LightGridLeaf

pub fn cells(&self) -> &[LightGridCell]

pub const fn cell_idx(&self, x: u32, y: u32, z: u32) -> usize

Returns the index into data of the cell at the position specified.

pub fn get_cell(&self, x: u32, y: u32, z: u32) -> &LightGridCell

Returns the cell at the specified position, panics if the position is out of bounds.

pub fn get_cell_mut(&mut self, x: u32, y: u32, z: u32) -> &mut LightGridCell

Returns the cell at the specified position, panics if the position is out of bounds.

pub const fn size(&self) -> UVec3