pub struct ByteLightmapOffset {
pub byte_offset: i32,
}Expand description
An offset specified in number of bytes.
Fields
byte_offset: i32The offset from the start of the lightmap, in bytes, that the lightmap for this face starts.