pub struct PixelLightmapOffset {
pub pixel_offset: i32,
}Expand description
An offset specified in number of pixels.
Fields
pixel_offset: i32The offset from the start of the lightmap, in pixels, that the lightmap for this face starts.