BspEdge

Struct BspEdge 

pub struct BspEdge {
    pub a: UBspValue,
    pub b: UBspValue,
}
A single edge in a BSP model.

Fields

a: UBspValue

The index to the first vertex this edge connects

b: UBspValue

The index to the second vertex this edge connects