Module texture

Module texture 

Data definitions for textures and surface flags.

Structs

BspMipTexture
Embedded texture data. GoldSrc stores these in a separate lump.
BspSurfaceFlags
BspTexInfo
BspTexInfoFlags
BspTexQ2Info
Extra info stored directly on the BspTexInfo - for Quake 2 (which does not have a lump for embedded textures).
BspTextureData
BspTextureHeader
Palette
An id Tech 2 palette to use for embedded images.
PlanarTextureProjection
Texture projection information.
Q2InfoField
TextureIdxField
Wad3Palette
GoldSrc (BSP30) levels can have per-texture pallettes stored in WAD files with the WAD3 format.

Enums

BspTexFlags
Quake 1-style texture flags. Quake 2 ditches this entirely, GoldSrc mostly handles this on a per-brush basis using rendermode and related entity keys.

Type Aliases

EmbeddedTextureName
Stack-allocated string the longest an embedded texture name can be.
TextureName
Stack-allocated string the longest a texture name can be.