pub struct LightGridLeaf {
pub mins: UVec3,
/* private fields */
}Fields
mins: UVec3Implementations
Sourceimpl LightGridLeaf
impl LightGridLeaf
pub fn cells(&self) -> &[LightGridCell]
Sourcepub const fn cell_idx(&self, x: u32, y: u32, z: u32) -> usize
pub const fn cell_idx(&self, x: u32, y: u32, z: u32) -> usize
Returns the index into data of the cell at the position specified.
Sourcepub fn get_cell(&self, x: u32, y: u32, z: u32) -> &LightGridCell
pub fn get_cell(&self, x: u32, y: u32, z: u32) -> &LightGridCell
Returns the cell at the specified position, panics if the position is out of bounds.
Sourcepub fn get_cell_mut(&mut self, x: u32, y: u32, z: u32) -> &mut LightGridCell
pub fn get_cell_mut(&mut self, x: u32, y: u32, z: u32) -> &mut LightGridCell
Returns the cell at the specified position, panics if the position is out of bounds.
pub const fn size(&self) -> UVec3