pub struct BspEdge {
pub a: UBspValue,
pub b: UBspValue,
}Expand description
A single edge in a BSP model.
Fields
a: UBspValueThe index to the first vertex this edge connects
b: UBspValueThe index to the second vertex this edge connects