Data definitions for textures and surface flags.
Structs
- BspMip
Texture - Embedded texture data. GoldSrc stores these in a separate lump.
- BspSurface
Flags - BspTex
Info - BspTex
Info Flags - BspTex
Q2Info - Extra info stored directly on the
BspTexInfo- for Quake 2 (which does not have a lump for embedded textures). - BspTexture
Data - BspTexture
Header - Palette
- An id Tech 2 palette to use for embedded images.
- Planar
Texture Projection - Texture projection information.
- Q2Info
Field - Texture
IdxField - Wad3
Palette - GoldSrc (BSP30) levels can have per-texture pallettes stored in WAD files with the WAD3 format.
Enums
- BspTex
Flags - Quake 1-style texture flags. Quake 2 ditches this entirely, GoldSrc
mostly handles this on a per-brush basis using
rendermodeand related entity keys.
Type Aliases
- Embedded
Texture Name - Stack-allocated string the longest an embedded texture name can be.
- Texture
Name - Stack-allocated string the longest a texture name can be.